@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine;
 # ABSTRACT: composable units of assertion
-$Test::Routine::VERSION = '0.019';
+$Test::Routine::VERSION = '0.024';
 #pod =head1 SYNOPSIS
 #pod
 #pod   # mytest.t
@@ -261,7 +261,7 @@ sub test {
   my $class = Moose::Meta::Class->initialize($caller);
 
   my %origin;
-  @origin{qw(file line nth)} = ((caller(0))[1,2], $i++);
+  @origin{qw(file line nth)} = ((caller(1))[1,2], $i++);
 
   my $method;
   if (blessed($body) && $body->isa('Class::MOP::Method')) {
@@ -289,6 +289,9 @@ sub test {
   Carp::croak "can't have two tests with the same name ($name)"
     if $class->get_method($name);
 
+  Carp::croak "there's already a subroutine named $name in $caller"
+    if $caller->can($name);
+
   Carp::croak "can't name a test after a Moose::Object method ($name)"
     if Moose::Object->can($name);
 
@@ -309,7 +312,7 @@ Test::Routine - composable units of assertion
 
 =head1 VERSION
 
-version 0.019
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -518,6 +521,34 @@ When you run it:
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Alex White Dagfinn Ilmari Mannsåker gregor herrmann Jesse Luehrs Yanick Champoux
+
+=over 4
+
+=item *
+
+Alex White <VVu@geekfarm.org>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+gregor herrmann <gregoa@debian.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Ricardo Signes.
