@@ -1,6 +1,6 @@
 package Test::Routine::Common;
 # ABSTRACT: a role composed by all Test::Routine roles
-$Test::Routine::Common::VERSION = '0.019';
+$Test::Routine::Common::VERSION = '0.024';
 use Moose::Role;
 
 #pod =head1 OVERVIEW
@@ -10,15 +10,22 @@ use Moose::Role;
 #pod
 #pod =cut
 
-use Test::More ();
+use Test::Abortable 0.002 ();
+use Test2::API 1.302045 ();
 
 use namespace::autoclean;
 
 sub run_test {
   my ($self, $test) = @_;
 
+  my $ctx = Test2::API::context();
+  my ($file, $line) = @{ $test->_origin }{ qw(file line) };
+  $ctx->trace->set_detail("at $file line $line");
+
   my $name = $test->name;
-  Test::More::subtest($test->description, sub { $self->$name });
+  Test::Abortable::subtest($test->description, sub { $self->$name });
+
+  $ctx->release;
 }
 
 1;
@@ -35,7 +42,7 @@ Test::Routine::Common - a role composed by all Test::Routine roles
 
 =head1 VERSION
 
-version 0.019
+version 0.024
 
 =head1 OVERVIEW
 
